@@ -7,7 +7,6 @@
 #pragma once
 
 #include <QIcon>
-#include <QList>
 #include <QObject>
 #include <QString>
 #include <QVariant>
@@ -81,7 +80,8 @@ public:
      */
     LogModeConfigurationWidget *logModeConfigurationWidget() const;
 
-    template<typename T> T logModeConfiguration()
+    template<typename T>
+    T logModeConfiguration()
     {
         return static_cast<T>(innerConfiguration());
     }
@@ -115,4 +115,3 @@ private:
      */
     LogModeConfiguration *innerConfiguration() const;
 };
-
